@@ -23,13 +23,20 @@
 
 #ifndef MOLEQUEUECLIENT_DEPRECATED
 #  define MOLEQUEUECLIENT_DEPRECATED __attribute__ ((__deprecated__))
-#  define MOLEQUEUECLIENT_DEPRECATED_EXPORT MOLEQUEUECLIENT_EXPORT __attribute__ ((__deprecated__))
-#  define MOLEQUEUECLIENT_DEPRECATED_NO_EXPORT MOLEQUEUECLIENT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MOLEQUEUECLIENT_NO_DEPRECATED
+#ifndef MOLEQUEUECLIENT_DEPRECATED_EXPORT
+#  define MOLEQUEUECLIENT_DEPRECATED_EXPORT MOLEQUEUECLIENT_EXPORT MOLEQUEUECLIENT_DEPRECATED
 #endif
 
+#ifndef MOLEQUEUECLIENT_DEPRECATED_NO_EXPORT
+#  define MOLEQUEUECLIENT_DEPRECATED_NO_EXPORT MOLEQUEUECLIENT_NO_EXPORT MOLEQUEUECLIENT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MOLEQUEUECLIENT_NO_DEPRECATED
+#    define MOLEQUEUECLIENT_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* MOLEQUEUECLIENT_EXPORT_H */
